import 'reflect-metadata';
import Base from './base';
import { MsError } from './Error';
import kafka from './kafka';
import { ConfService, DataRequest } from './types';
export declare abstract class Microservice extends kafka {
    /**
     * Aplicacion del resultado.
     * @protected
     */
    protected app: Base;
    /**
     * Coleccion de errores
     * @private
     * @type Map
     */
    private ErrorColl;
    /**
     * Hostname del nodo
     * @private
     */
    private hostname;
    /**
     * Contructor de la clase
     * @param conf Configuracion del servicio
     */
    constructor(conf: ConfService);
    /**
     * Metodo para el procesamiento de mensajes
     * @param data mensaje
     */
    message(data: DataRequest): Promise<any>;
    /**
     * Metodo para publicar un error en la cola de mensajes
     * @param service Nombre del servicio
     * @param transactionId Id de la transaccion
     * @param error Error
     */
    sendError(service: string, transactionId: string | number, error: any): void;
    /**
     * Metodo para publicar la respuesta
     * @param data Datos de respuesta
     * @param errorCode Codigo de error
     */
    response(data: DataRequest, errorCode: number, smoketest?: boolean): void;
    /**
     * Metodo que se ejecuta al ocurrir una excepcion al procesar mensajes.
     * @param topic Topico del Error
     * @param data Mensaje de la peticion
     * @param error Error que se ejecuta
     */
    exception(topic: string, data: string, error: Error): void;
    /**
     * Metodo para realizar la prueba de smoke Test
     * @public
     * @abstract
     */
    abstract smoketest(): boolean | Promise<boolean>;
    /**
     * Metodo que se ejecuta en el hellcheck
     * @publick
     */
    HellCheck(): boolean | Promise<boolean>;
    /**
     * Metodo para generar una excepcion en el codigo
     * @param code Codigo de error
     */
    protected emitError(code: number): MsError;
    /**
     * Metodo para iniciar el HellCheck HTTP
     * @private
     */
    private startHttpHellCheck;
    /**
     * Metodo para recuperar un Error.
     * @param code Codigo de Error
     */
    private getError;
    /**
     * Metodo para recuperar la configuracion de un elemento
     * registrado con los decoradores.
     * @param Name Nombre de la configuracion
     */
    private getConfHandler;
}
