"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
/**
 * Clase para la definicion y manejo del microservicio.
 */
class MsManager {
    /**
     * Metodo que ejecuta una clase
     * @param Target Clase a ejecutar
     */
    static execute(Target) {
        // Crear la instancia.
        const inst = new Target(Reflect.getMetadata('definition:conf', Target));
        // Ciclo infinito para no Terminar el proceso
        // setInterval(() => {
        // NO SE REQUIERE EJECUTAR NADA.
        // }, 500);
    }
    /**
     * Metodo para el el registro del micro servicio
     * @param Conf Configuracion del microservicio
     */
    static Define(Conf) {
        // Regresar la funcion decoradora
        return (Target) => {
            // Grabar la Configuracion
            Reflect.defineMetadata('definition:conf', Conf, Target);
            // Auto ejecutar la claxe
            MsManager.execute(Target);
            // Regresar el objeto inicial
            return Target;
        };
    }
    /**
     * @public
     * @static
     */
    static List() {
        // Indicar el tipo
        return MsManager.defineElement('definition:list');
    }
    /**
     * @public
     * @static
     */
    static Create() {
        // Indicar el tipo
        return MsManager.defineElement('definition:create');
    }
    /**
     * @public
     * @static
     */
    static Get() {
        // Indicar el tipo
        return MsManager.defineElement('definition:get');
    }
    /**
     * @public
     * @static
     */
    static Update() {
        // Indicar el tipo
        return MsManager.defineElement('definition:update');
    }
    /**
     * @public
     * @static
     */
    static Delete() {
        // Indicar el tipo
        return MsManager.defineElement('definition:delete');
    }
    /**
     * @public
     * @static
     */
    static Listener() {
        // Indicar el tipo
        return MsManager.defineElement('definition:listener');
    }
    /**
     * @public
     * @static
     */
    static Fork() {
        // Indicar el tipo
        return MsManager.defineElement('definition:fork');
    }
    static Errors() {
        // Indicar el tipo
        return MsManager.defineElement('definition:errors');
    }
    /**
     * Metodo para el registro Raw de un elemento de clase
     * @param conf Configuracion del elemento
     * @param type Tipo del elemento
     */
    static defineElement(Type) {
        // Regresar el objecto la funcion decoradora
        return (target, key, descriptor) => {
            const Conf = {
                key,
                returntype: Reflect.getMetadata('design:returntype', target, key),
                type: Reflect.getMetadata('design:type', target, key),
            };
            // Agregar la meta data del evento
            Reflect.defineMetadata(Type, Conf, target);
            // Regresar la funcion original
            return descriptor;
        };
    }
    /**
     * Metodo para recuperar toda la Meta data de un target
     * @param Target
     */
    static getAllMetaData(Target) {
        // Recuperar todas las Keys
        const Keys = Reflect.getMetadataKeys(Target);
        // Objeto donde se almacenaran los datos.
        const resulObj = [];
        // Recorrer y recuperar todos los datos
        for (const k of Keys) {
            // No recuperar los datos de configuracion
            if (k !== 'definition:conf') {
                // Almacenar la clave
                resulObj.push(Reflect.getMetadata(k, Target));
            }
        }
        // Regresar el resultado
        return resulObj;
    }
}
exports.MsManager = MsManager;
