import { ConfService, DataRequest, ResponseMessage } from './types';
/**
 * Clase base para los Worker y Fork
 */
export default abstract class Base {
    /**
     * Configuracion del servicio
     * @protected
     */
    protected config: ConfService;
    /**
     * Contructor de la clase
     * @param conf Configuracion del servicio
     */
    constructor(conf: ConfService);
    /**
     * Metodo que procesa el mensaje del servicio.
     * @abstract
     * @param data Datos del mensaje
     */
    abstract message(data: DataRequest, Method: () => void): Promise<any>;
    /**
     * Metodo para el envio de datos
     * @abstract
     * @param data Datos del mensaje
     * @param arg Cualquier otro argumento proporcionado
     * @returns ResponseMessage Regresa el objeto de respuesta
     */
    abstract formatResponse(data: DataRequest, ...arg: any[]): ResponseMessage;
}
