/// <reference types="node" />
import * as EventEmitter from 'events';
import { ConsumerGroup, KafkaClient, Producer } from 'kafka-node';
import { ConfService, DataRequest } from './types';
import Util from './util';
/**
 *  Clase para las conexiones y publicaciones sobre
 *  la cola de mensajes.
 */
export default abstract class Kafka extends Util {
    /**
     * Cliente a kafka
     * @protected
     */
    protected client: KafkaClient;
    /**
     * Producer kafka
     * @protected
     */
    protected producer: Producer;
    /**
     * Consumer kafka
     * @protected
     */
    protected consumer: ConsumerGroup;
    /**
     * Manejador de eventos
     * @protected
     */
    protected event: EventEmitter;
    /**
     * Manejador de logs
     * @protected
     */
    protected logs: any;
    /**
     * Configuracion del servicio
     * @protected
     */
    protected conf: ConfService;
    /**
     * Topico del servicio
     * @protected
     */
    protected Topic: string;
    /**
     * Servidores de kafka
     * @protected
     */
    protected kafkaHost: string[];
    /**
     * Contructor de la clase.
     * @param kafkaHost Servidores Kafka
     * @param Topic Topico de escucha
     */
    constructor(Conf: ConfService);
    /**
     * Metodo que procesa la peticion de mensajes.
     * @param data Datos de la peticion.
     */
    abstract message(data: DataRequest): Promise<any>;
    /**
     * Metodo para realizar la publicacion en la cola de mensajes
     * @param data Datos que se quieren publicar
     * @param errorCode Codigo de error
     */
    abstract response(data: DataRequest, errorCode: string | number): void;
    /**
     * Metodo que se ejecuta al ocurrir un excepcion
     * @param topic Topico que se escucha
     * @param data Datos proporcionados
     * @param error Error que se genero
     */
    abstract exception(topic: string, data: string, error: Error): void;
}
